@@ -1,19 +1,16 @@
-"""
-from rest_framework.serializers import ModelSerializer
-
-from nb_service.models import MyModel1
-
-
-class MyModel1Serializer(ModelSerializer):
-
-    class Meta:
-        model = MyModel1
-        fields = '__all__'
-"""
 from drf_yasg.utils import swagger_serializer_method
 from rest_framework import serializers
 from django.contrib.contenttypes.models import ContentType
-from netbox.api import ChoiceField, ContentTypeField, WritableNestedSerializer
+
+from django.conf import settings
+from packaging import version
+NETBOX_CURRENT_VERSION = version.parse(settings.VERSION)
+if NETBOX_CURRENT_VERSION >= version.parse("3.3"):
+    from netbox.api.fields import ChoiceField, ContentTypeField
+    from netbox.api.serializers import WritableNestedSerializer
+else:
+    from netbox.api import ChoiceField, ContentTypeField, WritableNestedSerializer
+
 from utilities.api import get_serializer_for_model
 from tenancy.api.nested_serializers import NestedTenantSerializer
 from ipam.choices import ServiceProtocolChoices
@@ -105,4 +102,4 @@ class nb_ServiceSerializer(serializers.Serializer):
 
     class Meta:
         model = models.Service
-        fields = ['id', 'display', 'name', 'clients', 'comments', 'backup_profile']
\ No newline at end of file
+        fields = ['id', 'display', 'name', 'clients', 'comments', 'backup_profile']
